
# Slot: start interbase coordinate


The position at which the subject genomic entity starts on the chromosome or other entity to which it is located on.

URI: [biolink:start_interbase_coordinate](https://w3id.org/biolink/vocab/start_interbase_coordinate)


## Domain and Range

[GenomicSequenceLocalization](GenomicSequenceLocalization.md) &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents

 *  is_a: [interbase coordinate](interbase_coordinate.md)

## Children


## Used by

 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
